summaryrefslogtreecommitdiff
path: root/response.c
diff options
context:
space:
mode:
Diffstat (limited to 'response.c')
-rw-r--r--response.c6
1 files changed, 3 insertions, 3 deletions
diff --git a/response.c b/response.c
index 2321937..11cd504 100644
--- a/response.c
+++ b/response.c
@@ -61,7 +61,7 @@ gboolean cbClientInput(gpointer data, gpointer additional)
return FALSE;
}
//emit a signal which calls the echoCb function
SignalObjectClass myStruct;
myStruct.instance = NULL;
myStruct.cb = writeOutput;
@@ -92,11 +92,11 @@ void initSignals(guint *signal)
g_cclosure_marshal_VOID__POINTER , G_TYPE_NONE, 1, G_TYPE_POINTER);
signalObject = g_object_new(SIGNAL_OBJECT_TYPE, NULL);
- g_signal_connect (signalObject, "runEchoService", G_CALLBACK (echoCb), NULL);
+ g_signal_connect (signalObject, "runEchoService", G_CALLBACK (responseCb), NULL);
}
//send to client 3 times
-void echoCb(gpointer instance, GObject *arg1, gpointer user_data)
+void responseCb(gpointer instance, GObject *arg1, gpointer user_data)
{
static GStaticMutex mutex = G_STATIC_MUTEX_INIT;
g_static_mutex_lock (&mutex);
@@ -61,7 +61,7 @@ gboolean cbClientInput(gpointer data, gpointer additional)
return FALSE;
}
- //emit a signal which calls the echoCb function
+ //emit a signal which calls the responseCb function
SignalObjectClass myStruct;
myStruct.instance = NULL;